lifecycle/lifecycle_data library

Classes

LifecycleExtData
寄存于lifecycle的数据 基类
LifecycleRegistryExtData
寄存于lifecycle的数据
LiveExtData
寄存于lifecycle的数据
TypedKey<T>
以泛型类型和 key 参数作为索引 A key class that uses both a generic type T and an optional key as an index.

Extensions

LifecycleRegistryTypedDataExt on ILifecycleRegistry
LifecycleTypedDataExt on Lifecycle

Typedefs

LifecycleExtDataOnDestroy<T> = void Function(T data)